<?php
/**
 * @package    CAdvancedSlideshow
 * @author     Yves Hoppe <yves@compojoom.com>
 * @date       20.09.13
 *
 * @copyright  Copyright (C) 2008 - 2013 compojoom.com . All rights reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE
 */

defined('_JEXEC') or die ('Restricted access');

/**
 * Class CAdvancedSlideshowHelperBasic
 *
 * @since  1.0
 */
class CAdvancedSlideshowHelperBasic
{
	private static $instance;

	/**
	 * Gets the template name matching to given int
	 *
	 * @param   int  $num  - The template number
	 *
	 * @return  string
	 */
	public static function getTemplateName($num)
	{
		switch ($num)
		{
			case 1:
				return "modern";
			case 2:
				return "spacy";
			default:
				return "default";
		}
	}

	/**
	 * Generates the footer
	 *
	 * @return  string
	 */
	public static function footer()
	{
		$footer = '<p style="text-align: center; margin-top: 15px;" class="copyright"> ';
		$footer .= 'CAdvancedSlideshow - Yet another slideshow for <a href="http://joomla.org" target="_blank">Joomla!™</a>';
		$footer .= ' by <a href="https://compojoom.com">compojoom.com</a>';
		$footer .= '</p>';

		return $footer;
	}

	/**
	 * Loads the slides
	 *
	 * @param   int     $gid   - The gallery id
	 * @param   string  $lang  - The language
	 *
	 * @return mixed
	 */
	public static function getSlides($gid, $lang)
	{
		$db = JFactory::getDBO();
		$query = $db->getQuery(true);

		$date = JFactory::getDate("now");

		$query->select('*')->from('#__cadvancedslideshow_slides')
			->where(
				array('galleryid = ' . $db->quote($gid),
				'published = 1', "((published_up < " . $db->quote($date->toSql()) . ") or (published_up = '0000-00-00 00:00:00'))", // 10.1
				"((published_down > " . $db->quote($date->toSql()) . ") or (published_down = '0000-00-00 00:00:00'))"
				)
			);

		if (!empty($lang))
		{
			$query->where('lang = ' . $db->quote($lang));
		}

		$db->setQuery($query);

		return $db->loadObjectList();
	}

	/**
	 * Generates the menu
	 *
	 * @return  array
	 */
	public static function getMenu()
	{
		$menu = array(

			'slides' => array(
				'link' => '', 'title' => 'COM_CADVANCEDSLIDESHOW_SLIDES', 'icon' => 'fa-picture-o', 'anchor' => '', 'children' => array(), 'label' => '',
				'keywords' => 'slides'
			),

			'categories' => array(
				'link' => 'index.php?option=com_categories&extension=com_cadvancedslideshow', 'title' => 'COM_CADVANCEDSLIDESHOW_GALLERIES',
				'icon' => 'fa-book', 'anchor' => '', 'children' => array(), 'label' => '',
				'keywords' => 'gallery'
			),

			'information' => array(
				'link' => '', 'title' => 'COM_MATUKIO_INFORMATIONS', 'icon' => ' fa-info-circle', 'anchor' => '', 'children' => array(), 'label' => '',
				'keywords' => 'informations version'
			),
		);

		return $menu;
	}
}
